/*
 * FILTER_PCR_DUP
 * Delete PCR duplicates reads with PICARD MarkDuplicates
 */

include { SAMTOOLS_SORT } from '../../modules/nf-core/custom/samtools/sort/main'
include { SAMTOOLS_SORT_N } from '../../modules/nf-core/custom/samtools_n/sort/main'
include { FILTER_PAIR } from '../../modules/local/filterbam/main'
include { SAMTOOLS_INDEX } from '../../modules/nf-core/custom/samtools/index/main'
include { PICARD_MARKDUPLICATES } from '../../modules/nf-core/custom/picard/markduplicates/main'

workflow FILTER_PCR_DUP {

    take:
    bam
    fasta
    index

    main:

    SAMTOOLS_SORT(
        bam
    )

    PICARD_MARKDUPLICATES(
        SAMTOOLS_SORT.out.bam,
        fasta.collect(),
        index.collect()
    )

    SAMTOOLS_SORT_N(
        PICARD_MARKDUPLICATES.out.bam
    )
    SAMTOOLS_SORT_N.out.bam.set{ ch_bam }

    FILTER_PAIR(
    ch_bam.combine(ch_bam)
    .map {
        meta1, bam1, meta2, bam2 ->
            meta1.id == meta2.id && meta1.chunk == meta2.chunk && meta1.mates == "R1" && meta2.mates == "R2" ? [ meta1,  bam1,  meta2, bam2 ] : null
    })
    FILTER_PAIR.out.bam.set{ new_ch_bam }

    emit:
    bam = new_ch_bam
}
